<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>SelectAll</name>
    <message>
        <location filename="../SelectAllInit.js" line="+2"/>
        <source>Select &amp;All</source>
        <translation>&amp;Vybrat vše</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Select all visible entities</source>
        <translation>Vybrat všechny viditelné objekty</translation>
    </message>
</context>
</TS>
